function mark2file
% MARK Mark landmarks in images and saves coordinates to a file.
%
%  Mark points with the left mouse button.
%  Esc-key to delete last landmark.
%  Press any other key to abort.
%  Right mouse button to finish.

% Copyright (c) 2001-2002 by Finn Lindgren
% $Revision: 1.4 $  $Date: 2002/05/01 22:56:26 $
% Modified by Vlad Atanasiu 07/02/2008

version = 'v2008.02.07';
repeat = 1;
pathname = [];
% repeat until escape key is hit
while repeat == 1
    pathnameold = pathname;
	% select image of allowed file formats
	[filename,pathname] = uigetfile(...
		{'*.jpg;*.jpeg;*.tif;*.tiff;*.bmp;*.png;*.pcx;*.hdf;*.xwd', '> Images'; ...
		'*.jpg;*.jpeg', 'JPG, JPEG';...
		'*.tif;*.tiff', 'TIFF uncompressed'; ...
		'*.bmp',        'BMP'; ...
		'*.png',        'PNG'; ...
		'*.pcx',        'PCX'; ...
		'*.hdf',        'HDF'; ...
		'*.xwd',        'XWD'; ...
		'*.*',          'All Files (*.*)'}, ...
		'Load image');

	% exit if no file or no directory selected
	if filename ~= 0 | pathname ~= 0
        if exist('p','var') == 0
            % open new figure if first image
            figure('NumberTitle','off')
        else
            % close existing fingure and open a new one
            % (needed as a sort of auto window resizing)
            close(gcf)
            figure('NumberTitle','off')
        end
        % continue
    else
        if pathnameold ~= 0
            helpdlg(['Data saved in: ',pathnameold,'landmarks.txt'],...
                ['mark2file ',version]);
        end
		return
	end

	% change current directory
	cd(pathname)

	% loads input image if any
	try
		IN = imread([pathname,filename]);
	catch
		continue % skip file that cannot be loaded
	end

	% show image
    if size(IN,3) > 1
        IN = rgb2gray(IN);
    end
    imshow(IN);
    set(gcf,'Name',[pathname, filename])
	title(['Mouse left: set landmark; '...
		'Mouse right: finish; '...
		'Escape key: delete last']);
	axis image

	% initialization
	N = Inf;
	d = 0;

	% make landmarks matrix
	if N < Inf
		p = zeros(2,N);
	else
		p = zeros(2,0);
	end
	
	% select landmarks
	for k = 1:N
		[x,y,btn] = ginput(1);
		if (isempty(btn) == 1 | (btn ~= 1 & btn ~= 27)) 
        % --- on mouse right-button
			p(:,k:end) = [];
			break
		elseif (btn == 27 & k ~= 1)
        % --- on ESC
			% delete last entry
			delete(h(k-d-1));
			% reset error counter
			d = d + 2;
			p = p(:,1:end-1);
		else 
        % --- on mouse left-button
			p(:,k-d) = [x;y];
			hold on
 			plot(p(1,k-d),p(2,k-d),'+r')
			h(k-d) = text(p(1,k-d), p(2,k-d), ...
                {[' ',int2str(k-d)],' '});
%             % write in negative color of background (actually: b/W)
%             % do check for roi-limits out of image
%             roic = imhist(x(round(v)-5:round(v)+5,round(u)-5:round(u)+5),2);
%             if roic(1) > roic(2)
%                 roic = 1;
%             else
%                 roic = 0;
%             end
%             set(h,'color',[roic roic roic],'horizontal','center','vertical','middle')
			set(h(k-d),'color','r',...
				'FontSize',14,...
				'horizontal','left','vertical','middle')
            % 'FontWeight','bold',...
            % 'FontName','FixedWidth',...
			hold off
		end
	end
	
	% transform coordinates to a string writable to a file
	resultsLandmarks = [];
    % add title to file
    if exist('landmarks.txt','file') == 0
        resultsLandmarks = 'Landmarks coordinates in images\n';
    end
    % add name of image
	resultsLandmarks = [resultsLandmarks,...
		strrep([pathname, filename],'\','/'), '\nx\t'];
    % add coordinates
	for m = 1:2	% 1st line: x; 2nd line: y
		for n = 1:size(p,2)
            % no decimals, tab btw. values
			resultsLandmarks = [resultsLandmarks,...
				num2str(p(m,n),'%1.0f')]; 
            if n ~= size(p,2)
                % add tab if not last landmark
                resultsLandmarks = [resultsLandmarks,'\t'];
            end
		end
		if m == 1
            % append line break after last landmark
			resultsLandmarks = [resultsLandmarks,'\ny\t']; 
		else
			resultsLandmarks = [resultsLandmarks,'\n'];
		end
	end
	
	% write coordinates to file
	resultsFile = fopen('landmarks.txt','at');
    fprintf(resultsFile,resultsLandmarks);
    fclose(resultsFile);
end
